@@ -32,6 +32,7 @@ function doDownload($filename, $fullPath, $absolute_dl)
       bindtextdomain('file_manager', '../plugins/file_manager/locale');
       textdomain('file_manager');
       echo '<h4>' . _("FILE DOES NOT EXIST OR PROBLEM OPENING FILE") . '</h4>';
+      bindtextdomain('squirrelmail', '../locale');
       textdomain('squirrelmail');
       echo '</body></html>';
       exit(1);
@@ -62,9 +63,14 @@ function doDownload($filename, $fullPath, $absolute_dl)
  */
 function DumpHeaders($type0, $type1, $filename, $fullPath, $force) {
 
+    if (defined('SM_PATH'))
+       include_once(SM_PATH . 'plugins/file_manager/functions.php');
+    else
+       include_once('../plugins/file_manager/functions.php');
+
     // get global variables for versions of PHP < 4.1
     //
-    if ((float)substr(PHP_VERSION,0,3) < 4.1) {
+    if (!compatibility_check_php_version(4, 1)) {
        global $HTTP_SERVER_VARS;
        $_SERVER = $HTTP_SERVER_VARS;
     }
@@ -138,7 +144,10 @@ function DumpHeaders($type0, $type1, $filename, $fullPath, $force) {
 function getMimeType($filename)
 {
 
-   include_once('../plugins/file_manager/mime_types.php');
+   if (defined('SM_PATH'))
+      include_once(SM_PATH . 'plugins/file_manager/mime_types.php');
+   else
+      include_once('../plugins/file_manager/mime_types.php');
 
    global $mimetypes;
 
